/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.database.columns;

import java.util.ArrayList;
import java.util.EnumSet;
import java.util.List;

import org.dussan.vaadin.dvirtual.database.Database;
import org.dussan.vaadin.dvirtual.i18n.Translation;

public enum ServerColumns
{

    ADDRESS( "address", Translation.FIELD_ADDRESS ),
    ENABLED( "enabled", Translation.FIELD_ENABLED ),
    MAX_USERS( "maxUsers", Translation.FIELD_USERS ),
    NAME( "name", Translation.FIELD_NAME ),
    NOTE( "note", Translation.FIELD_NOTE ),
    SELECTED( "selected", "selected" ),
    SSH_PORT( "sshPort", Translation.FIELD_SSH ),
    XPRA_MAX_PORT( "xpraMaxPort", Translation.FIELD_XPRA_MAX ),
    XPRA_MIN_PORT( "xpraMinPort", Translation.FIELD_XPRA_MIN ),
    XPRA_VERSION( "xpraVersion", Translation.FIELD_XPRA_VERSION );

    private String column = null;

    private String valueForTranslation = null;

    private ServerColumns( String column, String valueForTranslation )
    {
        this.column = column;
        this.valueForTranslation = valueForTranslation;
    }

    public String getColumn()
    {
        return column;
    }

    public String getValueForTranslation()
    {
        return valueForTranslation;
    }

    public String getName()
    {
        return name();
    }

    public String getSortAscending()
    {
        return name();
    }

    public String getSortDescending()
    {
        return Database.ORDER_DESCENDING + name();
    }

    public static final List<ServerColumns> getAllNames()
    {
        return ( new ArrayList<ServerColumns>( EnumSet.allOf( ServerColumns.class ) ) );
    }

}
