/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.database.data;

import java.io.Serializable;
import java.util.Date;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

import org.apache.commons.lang3.StringUtils;

@Entity( name = "UserSessionData" )
@Table( name = "dv_user_session" )
public class UserSessionData
    implements Serializable
{

    private static final long serialVersionUID = -3784301345062132417L;

    public static final int DESKTOP_HEIGHT = 500;

    public static final int DESKTOP_WIDTH = 600;

    public static final int NEW_PORT = 0;

    public static final int UNDEFINED_WINDOW = -1;

    public static final int NEW_WINDOW = 0;

    public static final int REMOVE_USER_SESSION = -1;

    public static final long NEW_USER_SESSION = 0;

    public static final long UNDEFINED_USER_SESSION = -1;

    public static final Boolean DEFAULT_LOCKED = Boolean.TRUE;

    public static final String NEW_CANVAS_ID = "__canvas__";

    public static final String NEW_DATA = StringUtils.EMPTY;

    @Id
    @GeneratedValue( strategy = GenerationType.AUTO )
    private Long id;

    @ManyToOne
    @JoinColumn( name = "user_id", referencedColumnName = "id", nullable = false )
    private UserData userData;

    @ManyToOne
    @JoinColumn( name = "server_id", referencedColumnName = "id", nullable = false )
    private ServerData serverData;

    @Column( name = "port", nullable = false )
    private Integer port;

    @ManyToOne
    @JoinColumn( name = "application_id", referencedColumnName = "id", nullable = false )
    private ApplicationData applicationData;

    @Column( name = "status", length = 2000, nullable = true )
    private String status;

    @Column( name = "canvas_id", length = 40, nullable = false )
    private String canvasId;

    @Column( name = "desktop_width", nullable = false )
    private Integer desktopWidth;

    @Column( name = "desktop_height", nullable = false )
    private Integer desktopHeight;

    @Column( name = "window_id", nullable = true )
    private Integer windowId;

    @Column( name = "locked", nullable = false )
    private Boolean locked;

    @Column( name = "updated", nullable = false )
    @Temporal( TemporalType.TIMESTAMP )
    private Date updated;

    public UserSessionData()
    {
        // nothing to do
    }

    public UserSessionData( long id, UserData userData, ServerData serverData, int port, ApplicationData applicationData, String status, String canvasId, int desktopWidth, int desktopHeight,
                            int windowId, boolean locked, Date updated )
    {
        setId( id );
        setUserData( userData );
        setServerData( serverData );
        setPort( port );
        setApplicationData( applicationData );
        setStatus( status );
        setCanvasId( canvasId );
        setDesktopWidth( desktopWidth );
        setDesktopHeight( desktopHeight );
        setWindowId( windowId );
        setLocked( locked );
        setUpdated( updated );
    }

    public Long getId()
    {
        return id;
    }

    public void setId( Long id )
    {
        this.id = id;
    }

    public UserData getUserData()
    {
        return userData;
    }

    public void setUserData( UserData userData )
    {
        this.userData = userData;
    }

    public ServerData getServerData()
    {
        return serverData;
    }

    public void setServerData( ServerData serverData )
    {
        this.serverData = serverData;
    }

    public Integer getPort()
    {
        return port;
    }

    public void setPort( Integer port )
    {
        this.port = port;
    }

    public ApplicationData getApplicationData()
    {
        return applicationData;
    }

    public void setApplicationData( ApplicationData applicationData )
    {
        this.applicationData = applicationData;
    }

    public String getStatus()
    {
        return status;
    }

    public void setStatus( String status )
    {
        this.status = StringUtils.stripToEmpty( status );
    }

    public String getCanvasId()
    {
        return canvasId;
    }

    public void setCanvasId( String canvasId )
    {
        this.canvasId = StringUtils.stripToEmpty( canvasId );
    }

    public Integer getDesktopWidth()
    {
        return desktopWidth;
    }

    public void setDesktopWidth( Integer desktopWidth )
    {
        this.desktopWidth = desktopWidth;
    }

    public Integer getDesktopHeight()
    {
        return desktopHeight;
    }

    public void setDesktopHeight( Integer desktopHeight )
    {
        this.desktopHeight = desktopHeight;
    }

    public Integer getWindowId()
    {
        return windowId;
    }

    public void setWindowId( Integer windowId )
    {
        this.windowId = windowId;
    }

    public Boolean isLocked()
    {
        return locked;
    }

    public void setLocked( Boolean locked )
    {
        this.locked = locked;
    }

    public Date getUpdated()
    {
        return updated;
    }

    public void setUpdated( Date updated )
    {
        this.updated = updated;
    }

    @Override
    public int hashCode()
    {
        final int prime = 31;
        int result = 1;
        result = prime * result + ( ( canvasId == null ) ? 0 : canvasId.hashCode() );
        result = prime * result + ( ( desktopHeight == null ) ? 0 : desktopHeight.hashCode() );
        result = prime * result + ( ( desktopWidth == null ) ? 0 : desktopWidth.hashCode() );
        result = prime * result + ( ( id == null ) ? 0 : id.hashCode() );
        result = prime * result + ( ( locked == null ) ? 0 : locked.hashCode() );
        result = prime * result + ( ( port == null ) ? 0 : port.hashCode() );
        result = prime * result + ( ( status == null ) ? 0 : status.hashCode() );
        result = prime * result + ( ( updated == null ) ? 0 : updated.hashCode() );
        result = prime * result + ( ( windowId == null ) ? 0 : windowId.hashCode() );
        return result;
    }

    @Override
    public boolean equals( Object obj )
    {
        if ( this == obj )
        {
            return true;
        }
        if ( obj == null )
        {
            return false;
        }
        if ( !( obj instanceof UserSessionData ) )
        {
            return false;
        }
        UserSessionData other = (UserSessionData) obj;
        if ( canvasId == null )
        {
            if ( other.canvasId != null )
            {
                return false;
            }
        }
        else if ( !canvasId.equals( other.canvasId ) )
        {
            return false;
        }
        if ( desktopHeight == null )
        {
            if ( other.desktopHeight != null )
            {
                return false;
            }
        }
        else if ( !desktopHeight.equals( other.desktopHeight ) )
        {
            return false;
        }
        if ( desktopWidth == null )
        {
            if ( other.desktopWidth != null )
            {
                return false;
            }
        }
        else if ( !desktopWidth.equals( other.desktopWidth ) )
        {
            return false;
        }
        if ( id == null )
        {
            if ( other.id != null )
            {
                return false;
            }
        }
        else if ( !id.equals( other.id ) )
        {
            return false;
        }
        if ( locked == null )
        {
            if ( other.locked != null )
            {
                return false;
            }
        }
        else if ( !locked.equals( other.locked ) )
        {
            return false;
        }
        if ( port == null )
        {
            if ( other.port != null )
            {
                return false;
            }
        }
        else if ( !port.equals( other.port ) )
        {
            return false;
        }
        if ( status == null )
        {
            if ( other.status != null )
            {
                return false;
            }
        }
        else if ( !status.equals( other.status ) )
        {
            return false;
        }
        if ( updated == null )
        {
            if ( other.updated != null )
            {
                return false;
            }
        }
        else if ( !updated.equals( other.updated ) )
        {
            return false;
        }
        if ( windowId == null )
        {
            if ( other.windowId != null )
            {
                return false;
            }
        }
        else if ( !windowId.equals( other.windowId ) )
        {
            return false;
        }
        return true;
    }

}
