/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.database.orders;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Order;
import javax.persistence.criteria.Root;

import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.dussan.vaadin.dvirtual.database.columns.UserSessionColumns;
import org.dussan.vaadin.dvirtual.database.data.UserData_;
import org.dussan.vaadin.dvirtual.database.data.UserSessionData;
import org.dussan.vaadin.dvirtual.database.data.UserSessionData_;

public class UserSessionOrder
    implements Serializable
{

    private static final long serialVersionUID = -826868651833634702L;

    public static final <T> CriteriaQuery<T> addOrder( CriteriaBuilder criteriaBuilder, CriteriaQuery<T> criteriaQuery, Root<UserSessionData> userSession, List<String> orders )
    {
        if ( CollectionUtils.isNotEmpty( orders ) )
        {
            List<Order> criteriaOrders = new ArrayList<>();
            for ( String order : orders )
            {
                if ( StringUtils.equals( order, UserSessionColumns.ACTIVE.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( userSession.get( UserSessionData_.locked ) ) );
                }
                else if ( StringUtils.equals( order, UserSessionColumns.ACTIVE.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( userSession.get( UserSessionData_.locked ) ) );
                }
                else if ( StringUtils.equals( order, UserSessionColumns.NAME_FULL.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( userSession.get( UserSessionData_.userData )
                                                                        .get( UserData_.fullName ) ) );
                }
                else if ( StringUtils.equals( order, UserSessionColumns.NAME_FULL.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( userSession.get( UserSessionData_.userData )
                                                                         .get( UserData_.fullName ) ) );
                }
                else if ( StringUtils.equals( order, UserSessionColumns.UPDATED.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( userSession.get( UserSessionData_.updated ) ) );
                }
                else if ( StringUtils.equals( order, UserSessionColumns.UPDATED.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( userSession.get( UserSessionData_.updated ) ) );
                }
            }
            return criteriaQuery.orderBy( criteriaOrders );
        }
        else
        {
            return criteriaQuery.orderBy( criteriaBuilder.asc( userSession.get( UserSessionData_.updated ) ) );
        }
    }

}
