/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.utils;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStream;
import java.io.Serializable;
import java.util.Arrays;
import java.util.Base64;
import java.util.zip.InflaterOutputStream;

import org.apache.commons.lang3.StringUtils;

public class CanvasImageUtil
    implements Serializable
{

    private static final long serialVersionUID = 7881248268978835379L;

    private static final int BUFFER_LENGTH = 16384;

    private CanvasImageUtil()
    {
        // nothing to do
    }

    public static String toBase64( Object value )
    {
        String base64 = StringUtils.EMPTY;
        if ( value instanceof byte[] )
        {
            base64 = new String( Base64.getEncoder()
                                       .encode( (byte[]) value ) );
        }
        return base64;
    }

    public static String toUint8Array( Object value )
    {
        if ( value instanceof byte[] )
        {
            byte[] values = (byte[]) value;
            int[] vals = new int[values.length];
            for ( int index = 0; index < ( (byte[]) value ).length; index++ )
            {
                vals[index] = Byte.toUnsignedInt( values[index] );
            }
            return Arrays.toString( vals );
        }
        return Arrays.toString( new int[] {} );
    }

    public static byte[] uncompress( Object value )
    {
        if ( value instanceof byte[] )
        {
            byte[] values = (byte[]) value;
            try (ByteArrayInputStream byteArrayInputStream = new ByteArrayInputStream( values );
                            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
                            OutputStream outputStream = new InflaterOutputStream( byteArrayOutputStream );)
            {
                int length = 0;
                byte[] buffer = new byte[BUFFER_LENGTH];
                while ( ( length = byteArrayInputStream.read( buffer ) ) > 0 )
                {
                    outputStream.write( buffer, 0, length );
                }
                return byteArrayOutputStream.toByteArray();
            }
            catch ( Exception exception )
            {
                return ( new byte[] {} );
            }
        }
        else
        {
            return ( new byte[] {} );
        }
    }

}
