/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.xpra.info;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

import org.apache.commons.lang3.StringUtils;

public enum PictureEncodingType
{

    JPEG( "jpeg" ), PNG( "png" ), RGB( "rgb" ), RGB24( "rgb24" ), RGB32( "rgb32" ), H264( "h264" ), SCROLL( "scroll" ), WEBP( "webp" ), UNDEFINED( "undefined" );

    private String type;

    private static String undefinedType;

    PictureEncodingType()
    {
        type = name();
    }

    PictureEncodingType( String type )
    {
        this.type = type;
    }

    public static PictureEncodingType getType( String type )
    {
        for ( PictureEncodingType t : PictureEncodingType.values() )
        {
            if ( StringUtils.equalsIgnoreCase( t.name(), type ) )
            {
                return t;
            }
        }
        undefinedType = type;
        return UNDEFINED;
    }

    public static PictureEncodingType getDefault()
    {
        return PictureEncodingType.PNG;
    }

    public static PictureEncodingType[] getAllTypes( boolean webpEnabled )
    {
        List<PictureEncodingType> types = new ArrayList<>();
        for ( PictureEncodingType type : PictureEncodingType.values() )
        {
            // XXX: for now disable H264 and SCROLL type
            if ( ( !type.equals( UNDEFINED ) && !type.equals( H264 ) && !type.equals( SCROLL ) && !type.equals( WEBP ) ) || ( webpEnabled && type.equals( WEBP ) ) )
            {
                types.add( type );
            }
        }
        return types.toArray( PictureEncodingType[]::new );
    }

    public static List<String> toStringList( PictureEncodingType[] types )
    {
        List<String> typeList = new ArrayList<>();
        if ( Objects.nonNull( types ) && types.length > 0 )
        {
            for ( PictureEncodingType type : types )
            {
                if ( !type.equals( UNDEFINED ) )
                {
                    typeList.add( type.toString() );
                }
            }
        }
        return typeList;
    }

    public String getUndefinedType()
    {
        return undefinedType;
    }

    @Override
    public String toString()
    {
        return type;
    }

}
