/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.xpra.packets.client;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.List;

import org.dussan.vaadin.dvirtual.xpra.packets.ClientPacket;
import org.dussan.vaadin.dvirtual.xpra.packets.PacketType;

public class ClientSuspendPacket
    extends ClientPacket
{

    private static final long serialVersionUID = -713672668823630488L;

    private boolean suspend = true;

    private List<Integer> windowIds = new ArrayList<>();

    public ClientSuspendPacket()
    {
        super( PacketType.Client.SUSPEND.toString() );
    }

    public ClientSuspendPacket( Integer... windowIds )
    {
        super( PacketType.Client.SUSPEND.toString() );
        this.windowIds = Arrays.asList( windowIds );
    }

    public boolean isSuspend()
    {
        return suspend;
    }

    public List<Integer> getWindowIds()
    {
        return windowIds;
    }

    public void setWindowIds( List<Integer> windowIds )
    {
        this.windowIds = windowIds;
    }

    @Override
    public void packPacket( Collection<Object> packetData )
    {
        packetData.add( getPacketType() );
        packetData.add( isSuspend() );
        packetData.add( getWindowIds() );
    }

}
