/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.xpra.packets.server;

import java.util.Iterator;
import java.util.Objects;

import org.dussan.vaadin.dvirtual.xpra.info.PictureEncodingType;
import org.dussan.vaadin.dvirtual.xpra.packets.PacketType;
import org.dussan.vaadin.dvirtual.xpra.packets.ServerPacket;

public class ServerCursorPacket
    extends ServerPacket
{

    private static final long serialVersionUID = 7850719596217637297L;

    private byte[] image = null;

    private int height = 0;

    private int x = 0;

    private int y = 0;

    private int width = 0;

    private PictureEncodingType encodingType = null;

    public ServerCursorPacket()
    {
        super( PacketType.Server.CURSOR.toString() );
    }

    public PictureEncodingType getEncodingType()
    {
        return encodingType;
    }

    public int getX()
    {
        return x;
    }

    public int getY()
    {
        return y;
    }

    public int getWidth()
    {
        return width;
    }

    public int getHeight()
    {
        return height;
    }

    public byte[] getImage()
    {
        return image;
    }

    @Override
    public void unpackPacket( Iterator<Object> packetData )
    {
        super.unpackPacket( packetData );

        int index = 0;
        while ( packetData.hasNext() )
        {
            switch ( index )
            {
                case 0:
                    encodingType = PictureEncodingType.getType( getString( packetData.next() ) );
                    index += 1;
                    break;
                case 3:
                    width = getInt( packetData.next() );
                    index += 1;
                    break;
                case 4:
                    height = getInt( packetData.next() );
                    index += 1;
                    break;
                case 5:
                    x = getInt( packetData.next() );
                    index += 1;
                    break;
                case 6:
                    y = getInt( packetData.next() );
                    index += 1;
                    break;
                case 8:
                    image = getByteArray( packetData.next() );
                    index += 1;
                    break;
                case 1:
                case 2:
                case 7:
                default:
                    packetData.next();
                    index += 1;
                    break;
            }
        }

        if ( index <= 3 )
        {
            // reset all cursors
            encodingType = PictureEncodingType.UNDEFINED;
        }
        else if ( Objects.isNull( getImage() ) )
        {
            // reset cursor of the active window
            x = -1;
            y = -1;
        }
    }

}
